Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewMainCommand ¶ added in v2.0.24
Types ¶
type GinEndpointDeclaration ¶ added in v2.2.9
type GinEndpointDeclaration interface {
Apply(target *gin.RouterGroup)
}
type GroupDeclaration ¶
type GroupDeclaration interface {
GinEndpointDeclaration
RegisterGroup(relativePath string, roles []string) GroupDeclaration
RegisterEndpoint(method string, roles []string, handlers ...gin.HandlerFunc)
RegisterEndpointPath(method string, relativePath string, roles []string, handlers ...gin.HandlerFunc)
}
type WebEngine ¶
type WebEngine struct {
context.Context
GroupDeclaration
// contains filtered or unexported fields
}
func NewWebEngine ¶
func WebEngineFromContext ¶
func (*WebEngine) Start ¶
Start needs a set of set env vars to work. they get set into the gin context and will be supplied to registered endpoints
JWT_ISSUER the token ISSUER that will be used to validate all provided tokens (i.e. https://auth.tiki-dsp.io/auth/realms/tiki)
OAUTH_CLIENT_ID the client that will be used to validate all provided tokens (i.e. ai-examples-python-dev-web-py36)
Click to show internal directories.
Click to hide internal directories.